/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

Originally from:
  http://www.arantius.com/article/lightweight+javascript+slider+control

Copyright (c) 2006 Anthony Lieuallen, http://www.arantius.com/

Permission is hereby granted, free of charge, to any person obtaining a copy of 
this software and associated documentation files (the "Software"), to deal in 
the Software without restriction, including without limitation the rights to 
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
the Software, and to permit persons to whom the Software is furnished to do so, 
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var knobImageWidth = 10;
var knobImageHalfWidth = 5;

function drawSliderByVal(slider) {
	var minP=(slider.minVal-slider.min)/(slider.max-slider.min);
	var minX=(slider.scrollWidth*minP)-knobImageHalfWidth;
	var minKnob=slider.getElementsByTagName('img')[0];
	minKnob.style.left=minX+"px";
	
	var maxP=(slider.maxVal-slider.min)/(slider.max-slider.min);
	var maxX=(slider.scrollWidth*maxP)-knobImageHalfWidth;
	var maxKnob=slider.getElementsByTagName('img')[1];
	maxKnob.style.left=maxX+"px";
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
function setSliderByClientX(slider, clientX) {
	var p=(clientX-slider.offsetLeft)/(slider.scrollWidth);
	
	var minKnob=slider.getElementsByTagName('img')[0];
	var maxKnob=slider.getElementsByTagName('img')[1];
	var position = (clientX-slider.offsetLeft);
	
	if((position > minKnob.offsetLeft && position < minKnob.offsetLeft + knobImageWidth) || (position >= 0 && position < minKnob.offsetLeft + knobImageHalfWidth)) {
		slider.minVal = (slider.max-slider.min)*p + slider.min;
	}else if((position > maxKnob.offsetLeft && position < maxKnob.offsetLeft + knobImageWidth) || (position <= slider.scrollWidth && position > maxKnob.offsetLeft + knobImageHalfWidth)) {
		slider.maxVal = (slider.max-slider.min)*p + slider.min;
	}
	
	if(slider.maxVal>slider.max) {
		slider.maxVal=slider.max;
	}
	if(slider.minVal<slider.min) { 
		slider.minVal=slider.min;
	}
	if(slider.minVal>=slider.maxVal) {
		slider.minVal=slider.maxVal-1;
	}

	drawSliderByVal(slider);
	slider.onchange(slider.minVal, slider.maxVal, slider.num);
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
function sliderClick(e) {
	var el=sliderFromEvent(e);
	if (!el) return;

	setSliderByClientX(el, e.clientX);
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
function sliderMouseMove(e) {
	var el=sliderFromEvent(e);
	if (!el) {
		activeSlider = -1; // added by ziv
	 	return;
	}
	if (activeSlider<0) return;
	setSliderByClientX(el, e.clientX);
	stopEvent(e);
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
function sliderFromEvent(e) {
	if (!e && window.event) e=window.event;
	if (!e) return false;

	var el;
	if (e.target) el=e.target;
	if (e.srcElement) el=e.srcElement;

	if (!el.id || !el.id.match(/slider\d+/)) el=el.parentNode;
	if (!el) return false;
	if (!el.id || !el.id.match(/slider\d+/)) return false;

	return el;
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
function attachSliderEvents() {
	var divs=document.getElementsByTagName('div');
	var divNum;
	for(var i=0; i<divs.length; i++) {
		if (divNum=divs[i].id.match(/\bslider(\d+)\b/)) {
			// set initial properties
			divNum=parseInt(divNum[1]);
			divs[i].min=slider[divNum].min;
			divs[i].max=slider[divNum].max;
			divs[i].minVal=slider[divNum].minVal;
			divs[i].maxVal=slider[divNum].maxVal;
			divs[i].onchange=slider[divNum].onchange;
			divs[i].num=divNum;
			// and make sure the display matches
			if(divs[i].className != "NONE") {
				drawSliderByVal(divs[i]);
			}
			divs[i].onchange(divs[i].minVal, divs[i].maxVal, divNum);

			addAnEvent(divs[i], 'mousedown', function(e){
				sliderClick(e);
				var el=sliderFromEvent(e);
				if (!el) return;
				activeSlider=el.num;
				stopEvent(e);
			});
			addAnEvent(divs[i], 'mouseup', function(e, divNum){
				var doMouseUp = true;
				if(activeSlider == -1) {
					doMouseUp = false;
				}
				activeSlider=-1;
				stopEvent(e);
				if(doMouseUp) {
					sliderMouseUp(e);
				}
			});
		}
	}
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
//borrowed from prototype: http://prototype.conio.net/
function stopEvent(event) {
	if (event.preventDefault) {
		event.preventDefault();
		event.stopPropagation();
	} else {
		event.returnValue=false;
		event.cancelBubble=true;
	}
}
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
//addAnEvent(window, 'load', attachSliderEvents);
addAnEvent(document, 'mousemove', sliderMouseMove);
var activeSlider=-1;
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//add event function from http://www.dynarch.com/projects/calendar/
function addAnEvent(el, evname, func) {
  if (el.attachEvent) { // IE
      el.attachEvent("on" + evname, func);
  } else if (el.addEventListener) { // Gecko / W3C
      el.addEventListener(evname, func, true);
  } else {
      el["on" + evname] = func;
  }
}
