var windowWidth = 1280;
var windowHeight = 768;

function showSearchLoadingMessage(params) {
	resetView();
}

function resetView() {
	showDivLoadingImage(HEADER_DIV_ID);
	clearDiv(GRAPH_DIV_ID);
	clearDiv(MAIN_TABLE_DIV_ID);
}

function clearDiv(divId) {
	var div = document.getElementById(divId);
	if(div) {
		replaceDivContent(divId, "");
	}
}

function getParamValuesArray(params, paramName) {
	var paramsArr = params.split("&");
	var keyValueArr;
	var paramValuesArr;
	for(var i = 0; i < paramsArr.length; i++) {
		keyValueArr = paramsArr[i].split("=");
		if(keyValueArr[0] == paramName) {
			paramValuesArr = keyValueArr[1].split("|");
			break;
		}
	}
	return paramValuesArr;
}

function doOnLoad(resetModel, searchTerm) {
	init();
	
	loadData(resetModel, searchTerm);
	
	loadCalendar();
}

function init() {
	initDimnesions();
}

function initDimnesions() {
	var windowSizeArr = getWidthAndHeight();
	var divWidth = document.getElementById(GRAPH_DIV_ID).clientWidth;
	if (windowSizeArr && windowSizeArr.length == 2){
		//windowWidth = windowSizeArr[0];
		windowWidth = divWidth - 20;//use graph div width instead of window width
		windowHeight = windowSizeArr[1];
	}
}

function doOnUnload() {
	clearTimeoutObjects();
}

function clearTimeoutObjects() {
	clearActiveSearchViewUpdaterTimeoutObject();
}

var resetInProgress = false;
function doReset() {
	resetInProgress = true;
	loadData(true, '');
}

function doSearch() {
	var searchTerm = document.getElementById("searchTerm");
	if(!searchTerm || searchTerm.value == "") {
		return;
	}
	updateSearchModel("action=search&searchTerm=" + encodeURIComponent(searchTerm.value));
}

function doSearchHistory(searchTerm) {
	updateSearchModel("action=search&searchTerm=" + encodeURIComponent(searchTerm));
}

function loadData(resetModel, searchTerm) {
	var params = "action=loadData&resetModel=" + resetModel;
	if(searchTerm && searchTerm != '') {
		params = "action=search&searchTerm=" + encodeURIComponent(searchTerm);
	}
	updateSearchModel(params);
}

function resetModel() {
	updateSearchModel("action=loadData&resetModel=true");
}

function updateSearchModel(params) {
	clearTimeoutObjects();
	hideFloatingDivs();
	var actionArr = getParamValuesArray(params, "action");
	if(!actionArr || (actionArr[0] != "changeViewType" && 
			  		  actionArr[0] != "changeViewGroupType" && 
			  		  actionArr[0] != "toggleDashboardAnalysis" && 
			  		  actionArr[0] != "toggleEventsCollapsed" &&
			  		  actionArr[0] != "changeRecordsPerPage" &&
					  !isPagingAction(actionArr[0]))) {
		showSearchLoadingMessage(params);
	}
	if(isPagingAction(actionArr[0])) {
		onPagingAction();
	}
	var postParams = "";
	if(params) {
		postParams += params;
	}
	sendAjaxRequest("updateSearchModel.jsp", function(req){
	    var xmldoc = req.responseXML.documentElement;
	    if(xmldoc) {
	      var responseElement = xmldoc.getElementsByTagName("Response")[0];
			if(responseElement) {
				var status = responseElement.getAttribute("status");
				if(status == STATUS_OK) {
					var viewType = responseElement.getAttribute("viewType");
					VIEW_TYPE = viewType;
					var action = responseElement.getAttribute("action");
					if(action && (action == "changeViewType" ||  action == "changeViewGroupType")) {
						loadDivDataLight(GRAPH_DIV_ID);
					}else if(action && (action == "toggleDashboardAnalysis" || action == "toggleEventsCollapsed" || action == "changeRecordsPerPage")) {
						loadDivDataLight(MAIN_TABLE_DIV_ID);
					}else if(isPagingAction(action)) {
						onAfterPagingAction(responseElement);
					}else {
						var divIds = responseElement.getAttribute("divIds");
						if(!divIds) {
							divIds = "";
						}
						var viewBy = responseElement.getAttribute("viewBy");
						VIEW_BY = viewBy;
						var rootNodeId = responseElement.getAttribute("rootNodeId");
						var rootNodeType = responseElement.getAttribute("rootNodeType");
						var runningMode = responseElement.getAttribute("runningMode");
						var isEmptySearch = responseElement.getAttribute("isEmptySearch");
						var isErrorQuery = responseElement.getAttribute("isErrorQuery");
						var errorTitle = responseElement.getAttribute("errorTitle");
						var errorMessage = responseElement.getAttribute("errorMessage");
						var errorQuery = responseElement.getAttribute("errorQuery");
						
						loadDivsData(action, divIds, rootNodeId, rootNodeType, runningMode, isEmptySearch, isErrorQuery, errorTitle, errorMessage, errorQuery);
					}
				}else {
					if(status == STATUS_NO_ACTION) {
						
					}else {
						alert("error in updateSearchModel");
					}
				}
			}else {
		    	var message = "search.js, updateSearchModel, responseElement, params=" + postParams;
		    	if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
		    		message += ", " + req.responseText;
		    	}
				doLogJsError(BASE_DIRECTORY, message);
		    }
		}else {
	    	var message = "search.js, updateSearchModel, xmldoc, params=" + postParams;
	    	if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
	    		message += ", " + req.responseText;
	    	}
			doLogJsError(BASE_DIRECTORY, message);
	    }
	  }, 'POST', postParams);
}

function hideFloatingDivs() {
	hideFloatingDiv("searchSyntaxDiv");
	hideFloatingDiv("searchCalendarDiv");
	hideFloatingDiv("searchFilterByDiv");
	hideFloatingDiv("searchFilterByTypeDiv");
	hideFloatingDiv("searchZoomInDiv");
	hideFloatingDiv("searchZoomInSmallImageDiv");
	hideFloatingDiv("searchErrorQueryDiv");
	hideGeneralAdminDiv("saveSearch");
	
	hideSearchGraphTooltip();
	hideTooltip();
}

function hideFloatingDiv(divId) {
	var div = document.getElementById(divId);
	if(div) {
		div.style.display = "none";
	}
}

var loadedDivs = new Array();
function loadDivsData(action, divIds, rootNodeId, rootNodeType, runningMode, isEmptySearch, isErrorQuery, errorTitle, errorMessage, errorQuery) {
	divIds = HEADER_DIV_ID;
	divIds = divIds.split("|");
	for(i = 0; i < divIds.length; i++) {
		loadDivData(action, divIds[i], '', rootNodeId, rootNodeType, runningMode, isEmptySearch, isErrorQuery, errorTitle, errorMessage, errorQuery);
	}
}

function loadDivData(action, divId, params, rootNodeId, rootNodeType, runningMode, isEmptySearch, isErrorQuery, errorTitle, errorMessage, errorQuery) {
	var postParams = "";
	if(params) {
		postParams += params;
	}
	if(divId == HEADER_DIV_ID || GRAPH_DIV_ID) {
		postParams += ("&windowWidth=" + windowWidth + "&windowHeight=" + windowHeight);
	}
	postParams += ("&divId=" + divId);
	
	showDivLoadingImage(divId);
	loadedDivs[divId] = false;
	
	sendAjaxRequest("searchDivContentFetcher.jsp", function(req){
	    var xmldoc = req.responseXML.documentElement;
	    if(xmldoc) {
	      var responseElement = xmldoc.getElementsByTagName("Response")[0];
			if(responseElement) {
				var responseDivId = responseElement.getAttribute("divId");
				if(responseDivId && responseDivId != "") {
					onAfterDivResponseLoaded(responseDivId, responseElement, rootNodeId, rootNodeType, runningMode, isEmptySearch, isErrorQuery, errorTitle, errorMessage, errorQuery);
				}else {
					var message = "search.js, loadDivData, responseDivId, divId=" + divId + ", params=" + postParams + ", runningMode=" + runningMode;
					if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
			    		message += ", " + req.responseText;
			    	}
					doLogJsError(BASE_DIRECTORY, message);
			    }
			}else {
				var message = "search.js, loadDivData, responseElement, divId=" + divId + ", params=" + postParams + ", runningMode=" + runningMode;
				if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
		    		message += ", " + req.responseText;
		    	}
				doLogJsError(BASE_DIRECTORY, message);
		    }
	    }else {
			var message = "search.js, loadDivData, xmldoc, divId=" + divId + ", params=" + postParams + ", runningMode=" + runningMode;
			if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
	    		message += ", " + req.responseText;
	    	}
			doLogJsError(BASE_DIRECTORY, message);
	    }
	}, 'POST', postParams);
}

var loadedDivsLight = new Array();
function loadDivDataLight(divId, handleSearchCompleted) {
	var postParams = "";
	if(divId == HEADER_DIV_ID || GRAPH_DIV_ID) {
		postParams += ("&windowWidth=" + windowWidth + "&windowHeight=" + windowHeight);
	}
	postParams += ("&divId=" + divId);
	
	loadedDivsLight[divId] = false;
	
	sendAjaxRequest("searchDivContentFetcher.jsp", function(req){
		var xmldoc = req.responseXML.documentElement;
	    if(xmldoc) {
	    	var responseElement = xmldoc.getElementsByTagName("Response")[0];
			if(responseElement) {
				var responseDivId = responseElement.getAttribute("divId");
				if(responseDivId && responseDivId != "") {
					var div = document.getElementById(responseDivId);
					if(div) {
						loadedDivsLight[divId] = true;
						
						var responseText = getXMLElementValue(responseElement);
						replaceDivContent(responseDivId, responseText);
						
						if(divId == GRAPH_DIV_ID) {
							onAfterGraphDivResponseLoaded();
						}else if(divId == MAIN_TABLE_DIV_ID) {
							onAfterMainTableDivResponseLoaded();
						}
						
						if(handleSearchCompleted && allDivsLightLoaded()) {
							stopSearchInProgressIndicator();
							showSearchCompleted();
						}
					}
				}else {
					var message = "search.js, loadDivDataLight, responseDivId, divId=" + divId + ", params=" + postParams;
					if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
			    		message += ", " + req.responseText;
			    	}
					doLogJsError(BASE_DIRECTORY, message);
			    }
			}else {
				var message = "search.js, loadDivDataLight, responseElement, divId=" + divId + ", params=" + postParams;
				if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
		    		message += ", " + req.responseText;
		    	}
				doLogJsError(BASE_DIRECTORY, message);
		    }
		}else {
			var message = "search.js, loadDivDataLight, xmldoc, divId=" + divId + ", params=" + postParams;
			if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
	    		message += ", " + req.responseText;
	    	}
			doLogJsError(BASE_DIRECTORY, message);
	    }
	}, 'POST', postParams);
}

function showDivLoadingImage(divId) {
	var div = document.getElementById(divId);
	if(div) {
		var loadingDivText = "<div id='loading" + divId + "' class='SEARCH_LOADING_DIV'><img src='" + BASE_DIRECTORY + "images/search/loadingAnimation.gif' border='0' />&nbsp;Loading...</div>";
		replaceDivContent(divId, loadingDivText);
	}
}

function onAfterDivResponseLoaded(divId, responseElement, rootNodeId, rootNodeType, runningMode, isEmptySearch, isErrorQuery, errorTitle, errorMessage, errorQuery) {
	var div = document.getElementById(divId);
	if(div) {
		var responseText = getXMLElementValue(responseElement);
		replaceDivContent(divId, responseText);
		
		loadedDivs[divId] = true;
		
		// perform onAfterLaoded actions only if all divs were loaded
		if(allDivsLoaded()) {
			onAfterHeaderDivResponseLoaded(isEmptySearch);
			onAfterCalendarDivResponseLoaded();
		}
		if(isErrorQuery && isErrorQuery == "true") {
			showErrorQuery(errorTitle, errorMessage, errorQuery);
		}else {
			if(resetInProgress) {
				resetInProgress = false;
			}else {
				if(runningMode != "0") {
					activateSearchViewUpdater();
				}else if(!isEmptySearch || isEmptySearch == "false"){
					onAfterSearchComplete(true);
				}
			}
		}
	}
}

function allDivsLoaded() {
	return loadedDivs[HEADER_DIV_ID] == true;
}

function allDivsLightLoaded() {
	return loadedDivsLight[GRAPH_DIV_ID] == true && loadedDivsLight[MAIN_TABLE_DIV_ID] == true;
}

function showErrorQuery(errorTitle, errorMessage, errorQuery) {
	var searchErrorQueryDiv = document.getElementById("searchErrorQueryDiv");
	var searchErrorQueryTd = document.getElementById("searchErrorQueryTd");
	if(searchErrorQueryDiv && searchErrorQueryTd) {
		var formattedErrorMessage = errorTitle + " " + errorMessage;
		if(errorQuery && errorQuery != "") {
			formattedErrorMessage = formattedErrorMessage + ": " + errorQuery;
		}
		replaceDivContent("searchErrorQueryTd", formattedErrorMessage);
		
		var width = $("#searchHeaderTextBoxCell").width();
		if(width) {
			searchErrorQueryDiv.style.width = width + "px";
		}
		
		var position = $("#searchHeaderTextBoxCell").position();
		if(position) {
			searchErrorQueryDiv.style.left = position.left + "px";
			searchErrorQueryDiv.style.top = (position.top + 30) + "px";
		}
		searchErrorQueryDiv.style.display = "";
	}
}

function clearActiveSearchViewUpdaterTimeoutObject() {
	if(activeSearchViewUpdaterTimeoutObject) {
		clearTimeout(activeSearchViewUpdaterTimeoutObject);
	}
}

var activeSearchViewUpdaterTimeoutObject;
function activateSearchViewUpdater() {
	startSearchInProgressIndicator();
	updateActiveSearchView(true);
}

function startSearchInProgressIndicator() {
	hideSearchInProgressImages();
	initSearchInProgressImage();
}

function hideSearchInProgressImages() {
	var searchInProgressTd = document.getElementById("searchInProgressTd");
	if(searchInProgressTd) {
		searchInProgressTd.style.display = "none";
	}
	var searchCompletedTd = document.getElementById("searchCompletedTd");
	if(searchCompletedTd) {
		searchCompletedTd.style.display = "none";
	}
}

function initSearchInProgressImage() {
	var searchInProgressImage = document.getElementById("searchInProgressImage");
	if(searchInProgressImage) {
		setImageSource(searchInProgressImage, "header/searchInProgress.gif");
		var searchInProgressTd = document.getElementById("searchInProgressTd");
		if(searchInProgressTd) {
			searchInProgressTd.style.display = "";
		}
	}
}

function stopSearchInProgressIndicator() {
	hideSearchInProgressImages();
}

function showSearchCompleted() {
	var searchCompletedTd = document.getElementById("searchCompletedTd");
	if(searchCompletedTd) {
		searchCompletedTd.style.display = "";
	}
}

var loadGraphIfNotRunning = true;
var loadTableIfNotRunning = true;
var graphLoadingImageVisible = false;
var tableLoadingImageVisible = false;
var loadPagingSectionOnly = true;
var timeoutCounter = 0;
function updateActiveSearchView(reset) {
	if(reset) {
		loadGraphIfNotRunning = true;
		loadTableIfNotRunning = true;
		graphLoadingImageVisible = false;
		tableLoadingImageVisible = false;
		loadPagingSectionOnly = true;
		timeoutCounter = 0;
	}
	sendAjaxRequest("searchStatus.jsp", function(req){
	    var xmldoc = req.responseXML.documentElement;
	    if(xmldoc) {
	    	var responseElement = xmldoc.getElementsByTagName("Response")[0];
			if(responseElement) {
				if(!resetInProgress) {
					var runningMode = responseElement.getAttribute("runningMode");
					var numberOfLogsMatched = responseElement.getAttribute("numberOfLogsMatched");
					var recordsPerPage = responseElement.getAttribute("recordsPerPage");
					var numberOfRecordsInCurrentPage = responseElement.getAttribute("numberOfRecordsInCurrentPage");
					if(runningMode && runningMode != "0") {
						if(overTimeRunning(runningMode) || loadGraphIfNotRunning) {
							if(numberOfLogsMatched && numberOfLogsMatched == "0") {
								showDivLoadingImage(GRAPH_DIV_ID);
								graphLoadingImageVisible = true;
							}else {
								loadDivDataLight(GRAPH_DIV_ID);
							}
							loadGraphIfNotRunning = false;
						}else if(graphLoadingImageVisible){
							graphLoadingImageVisible = false;
							loadDivDataLight(GRAPH_DIV_ID);
						}
						if(logsResultsRunning(runningMode) || loadTableIfNotRunning) {
							if(overTimeRunning(runningMode) && numberOfLogsMatched && numberOfLogsMatched == "0") {
								showDivLoadingImage(MAIN_TABLE_DIV_ID);
								tableLoadingImageVisible = true;
							}else {
								if(parseInt(numberOfRecordsInCurrentPage) < parseInt(recordsPerPage)) {
									loadDivDataLight(MAIN_TABLE_DIV_ID);
								}else {
									if(loadPagingSectionOnly) {
										loadDivDataLight(MAIN_TABLE_DIV_ID);
										loadPagingSectionOnly = false;
									}else {
										loadPagingSectionData();
									}
								}
							}
							loadTableIfNotRunning = false;
						}else if(tableLoadingImageVisible) {
							tableLoadingImageVisible = false;
							loadDivDataLight(MAIN_TABLE_DIV_ID);
						}
						
						var activeSearchViewUpdaterTimeoutInterval = 1000;
						if(timeoutCounter++ > 2) {
							// after 3 seconds, change the refresh interval from 1 second to 2.5 seconds
							activeSearchViewUpdaterTimeoutInterval = 2500;
						}
						activeSearchViewUpdaterTimeoutObject = setTimeout("updateActiveSearchView(false)", activeSearchViewUpdaterTimeoutInterval);
					}else {
						setTimeout("onAfterSearchComplete(true)", 500);
					}
				}else {
					var message = "search.js, updateActiveSearchView, !resetInProgress";
					if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
			    		message += ", " + req.responseText;
			    	}
					doLogJsError(BASE_DIRECTORY, message);
			    }
			}else {
				var message = "search.js, updateActiveSearchView, responseElement";
				if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
		    		message += ", " + req.responseText;
		    	}
				doLogJsError(BASE_DIRECTORY, message);
		    }
		}else {
			var message = "search.js, updateActiveSearchView, xmldoc";
			if(typeof printExtraDataOnError == "boolean" && printExtraDataOnError) {
	    		message += ", " + req.responseText;
	    	}
			doLogJsError(BASE_DIRECTORY, message);
	    }
	});
}

function loadPagingSectionData() {
	var searchMainTablePagingSectionCellHeader = document.getElementById("searchMainTablePagingSectionCellHeader");
	var searchMainTablePagingSectionCellFooter = document.getElementById("searchMainTablePagingSectionCellFooter");
	if(searchMainTablePagingSectionCellHeader && searchMainTablePagingSectionCellFooter) {
		sendAjaxRequest("searchMainTablePagingSection.jsp?isHeader=true", function(req){
			var responseText = req.responseText;
			if(responseText) {
				replaceDivContent("searchMainTablePagingSectionCellHeader", responseText);
			}
		});
		sendAjaxRequest("searchMainTablePagingSection.jsp?isHeader=false", function(req){
			var responseText = req.responseText;
			if(responseText) {
				replaceDivContent("searchMainTablePagingSectionCellFooter", responseText);
			}
		});
	}
}

function onAfterSearchComplete(doRefresh) {
	if(doRefresh) {
		refreshCurrentView(true);
	}
}

function refreshCurrentView(handleSearchCompleted) {
	loadDivDataLight(GRAPH_DIV_ID, handleSearchCompleted);
	loadDivDataLight(MAIN_TABLE_DIV_ID, handleSearchCompleted);
}

function showGraphDiv() {
	var graphDiv = document.getElementById(GRAPH_DIV_ID);
	if(graphDiv) {
		graphDiv.style.display = "";
	}
}

function hideGraphDiv() {
	var graphDiv = document.getElementById(GRAPH_DIV_ID);
	if(graphDiv) {
		graphDiv.style.display = "none";
	}
}

function overTimeRunning(runningMode) {
	return runningMode == "1" || runningMode == "2";
}

function logsResultsRunning(runningMode) {
	return runningMode == "1" || runningMode == "3";
}

function doCheckSearch(e){
	var result = doCheck(e);
	if (!result){
		doSearch();
	}
	return result;
}

function doCheck(e){
	if (!e) var e = window.event;
	if (e.keyCode) code = e.keyCode;
	else if (e.which) code = e.which;
	if (code == 13){
	  return false;
	}
	return true;
}

function showSlidingDiv(type, slidingDivId, referenceId, text, direction, stopPointInterval, refreshInterval, step) {
	if(type == "slide") {
		return slideDiv(slidingDivId, referenceId, text, direction, stopPointInterval, refreshInterval, step)
	}else if(type == "slideExpand") {
		return slideExpandDiv(slidingDivId, referenceId, text, direction, stopPointInterval, refreshInterval, step);
	}
}

function slideDiv(slidingDivId, referenceId, text, direction, stopPointInterval, refreshInterval, step) {
	var slidingDiv = document.getElementById(slidingDivId);
	if(slidingDiv) {
		slidingDiv.innerHTML = text;
		
		var reference = document.getElementById(referenceId);
		if(reference) {
			var left = findPosX(reference);
			var parsedLeft = parseInt(left);
			var stopPoint;
			if(direction == "right") {
				stopPoint = parsedLeft + stopPointInterval;
			}else if(direction == "left") {
				stopPoint = parsedLeft - stopPointInterval;
			}
			return setInterval("slideDiv0('" + slidingDivId + "', " + stopPoint + ", '" + direction + "', " + step + ")", refreshInterval);
		}
	}
}

function slideDiv0(slidingDivId, stopPoint, direction, step) {
	var slidingDiv = document.getElementById(slidingDivId);
	if(slidingDiv) {
		var divLeft = slidingDiv.style.left;
		var leftIndex = divLeft.indexOf("px");
		divLeft = divLeft.substring(0, leftIndex);
		var newLeft = parseInt(divLeft);
		if(direction == "right") {
			newLeft += step;
		}else if(direction == "left") {
			newLeft -= step;
		}
		if(direction == "right") {
			if(parseInt(divLeft) < parseInt(stopPoint)) {
				slidingDiv.style.left = (newLeft + "px");
			}
		}else if(direction == "left") {
			if(parseInt(divLeft) > parseInt(stopPoint)) {
				slidingDiv.style.left = (newLeft + "px");
			}
		}
	}
}

function slideExpandDiv(slidingDivId, referenceId, text, direction, stopPointInterval, refreshInterval, step) {
	var slidingDiv = document.getElementById(slidingDivId);
	if(slidingDiv) {
		slidingDiv.innerHTML = text;
		
		var reference = document.getElementById(referenceId);
		if(reference) {
			var left = findPosX(reference);
			var parsedLeft = parseInt(left);
			var stopPoint;
			if(direction == "right") {
				stopPoint = parsedLeft + stopPointInterval;
			}else if(direction == "left") {
				stopPoint = parsedLeft - stopPointInterval;
			}
			return setInterval("slideExpandDiv0('" + slidingDivId + "', " + stopPoint + ", '" + direction + "', " + step + ")", refreshInterval);
		}
	}
}

function slideExpandDiv0(slidingDivId, stopPoint, direction, step) {
	var slidingDiv = document.getElementById(slidingDivId);
	if(slidingDiv) {
		var divLeft = slidingDiv.style.left;
		var leftIndex = divLeft.indexOf("px");
		divLeft = divLeft.substring(0, leftIndex);
		var newLeft = parseInt(divLeft);
		if(direction == "left") {
			newLeft -= step;
		}
		
		var divWidth = slidingDiv.style.width;
		var widthIndex = divWidth.indexOf("px");
		divWidth = divWidth.substring(0, widthIndex);
		var newWidth = parseInt(divWidth);
		newWidth += step;
		
		var divRight = parseInt(divLeft) + parseInt(divWidth);
		
		if(direction == "right") {
			if(parseInt(divRight) < parseInt(stopPoint)) {
				slidingDiv.style.width = (newWidth + "px");
			}
		}else if(direction == "left") {
			if(parseInt(divLeft) > parseInt(stopPoint)) {
				slidingDiv.style.left = (newLeft + "px");
				slidingDiv.style.width = (newWidth + "px");
			}
		}
	}
}

function scrollToTop() {
	window.scroll(0, 0); 
}